#
# spec file for package python-PyYAML
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-PyYAML
Version:        5.1.2
Release:        lp151.2.13.1
Summary:        YAML parser and emitter for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/yaml/pyyaml
Source:         https://files.pythonhosted.org/packages/source/P/PyYAML/PyYAML-%{version}.tar.gz
Patch0:         pyyaml-5.1.2.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  libyaml-devel
BuildRequires:  python-rpm-macros
%ifpython2
# python-yaml was last used in openSUSE 12.1.
Provides:       %{oldpython}-yaml = %{version}
Obsoletes:      %{oldpython}-yaml < %{version}
%endif

%description
YAML is a data serialization format designed for human readability
and interaction with scripting languages. PyYAML is a YAML parser
and emitter for Python.

PyYAML features a complete YAML 1.1 parser, Unicode support, pickle
support, capable extension API, and sensible error messages. PyYAML
supports standard YAML tags and provides Python-specific tags that
allow to represent an arbitrary Python object.

PyYAML is applicable for a broad range of tasks from complex
configuration files to object serialization and persistance.

%python_subpackages

%prep
%setup -q -n PyYAML-%{version}
%patch0 -p1

%build
export CFLAGS="%{optflags}"
%python_build
# Fix example permissions.
find examples/ -type f | xargs chmod a-x

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# Increase file-descriptor-count for ppc to make tests happy.
%ifarch ppc ppc64 s390 s390x
ulimit -Sn 2048
%endif
%python_exec setup.py test

%files %{python_files}
%license LICENSE
%doc CHANGES README examples/
%{python_sitearch}/yaml
%{python_sitearch}/_yaml.*so
%{python_sitearch}/PyYAML-%{version}-py%{python_version}.egg-info

%changelog
* Fri Apr  3 2020 Tina Müller <tina.mueller@suse.com>
- Add patch pyyaml-5.1.2.patch (bsc#1165439 CVE-2020-1747)
  Prevents arbitrary code execution during python/object/* constructors
  (This patch contains the git commits 8c5e47f and 5080ba5 applied to the 5.1.2 release)
* Wed Nov 13 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1140565)
* Thu Aug  1 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 5.1.2
  * Re-release of 5.1 with regenerated Cython sources to build properly for Python 3.8b2+
* Fri Jun  7 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 5.1.1
  * Re-release of 5.1 with regenerated Cython sources to build properly for Python 3.8
* Thu Mar 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 5.1:
  * many changes, see CHANGES
  * bsc#1099308 CVE-2017-18342 PyYAML: yaml.load() API could execute arbitrary code
* Mon Jan 14 2019 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Sun Jul 15 2018 mimi.vx@gmail.com
- update to 3.13
  * fix compactibility with python 3.7
* Fri Mar  3 2017 sor.alexei@meowr.ru
- Use pythonhosted.org for the reference link.
- Provide python-yaml instead of python2-yaml again.
* Mon Feb 20 2017 jmatejek@suse.com
- update for multipython build
* Sat Sep  3 2016 mardnh@gmx.de
- Update to 3.12
  - Adding an implicit resolver to a derived loader should not
    affect the base loader (fixes issue #57).
  - Uniform representation for OrderedDict? across different
    versions of Python (fixes issue #61).
  - Fixed comparison to None warning (closes issue #64).
- fix Source URL
* Wed Jul 30 2014 toddrme2178@gmail.com
- Update to 3.11
  - Source and binary distributions are rebuilt against the latest
    versions of Cython and LibYAML.
* Wed Feb  5 2014 ro@suse.de
- increase file-descriptor-count for s390 to make tests happy
* Tue Mar  5 2013 dvaleev@suse.com
- increase file-descriptor-count for ppc to make tests happy
* Thu Jan 10 2013 p.drouand@gmail.com
- Initial python3 support
* Wed Dec 19 2012 saschpe@suse.de
- Build against libyaml to get the faster module
* Tue Jan 31 2012 saschpe@suse.de
- Initial version
